@@ -4,7 +4,10 @@ import typer
 
 APP_NAME = "my-super-cli-app"
 
+app = typer.Typer()
 
+
+@app.command()
 def main():
     app_dir = typer.get_app_dir(APP_NAME)
     config_path: Path = Path(app_dir) / "config.json"
@@ -13,4 +16,4 @@ def main():
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
