@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     name: Annotated[str, typer.Argument(help="Who to greet")],
     lastname: Annotated[
@@ -19,4 +22,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
