@@ -3,7 +3,10 @@ from typing import List
 
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(files: List[Path], celebration: str):
     for path in files:
         if path.is_file():
@@ -12,4 +15,4 @@ def main(files: List[Path], celebration: str):
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
