@@ -2,7 +2,10 @@ from typing import Tuple
 
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     names: Tuple[str, str, str] = typer.Argument(
         ("Harry", "Hermione", "Ron"), help="Select 3 characters to play with"
@@ -13,4 +16,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
