@@ -2,14 +2,17 @@ from typing import List, Optional
 
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(user: Optional[List[str]] = typer.Option(None)):
     if not user:
-        print("No provided users")
+        print(f"No provided users (raw input = {user})")
         raise typer.Abort()
     for u in user:
         print(f"Processing user: {u}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
