@@ -1,6 +1,10 @@
+from typing import Optional
+
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
+
 
 def name_callback(value: str):
     if value != "Camila":
@@ -8,9 +12,10 @@ def name_callback(value: str):
     return value
 
 
-def main(name: Annotated[str, typer.Option(callback=name_callback)]):
+@app.command()
+def main(name: Annotated[Optional[str], typer.Option(callback=name_callback)] = None):
     print(f"Hello {name}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
