@@ -3,6 +3,8 @@ from typing import Optional
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
+
 
 def name_callback(ctx: typer.Context, value: str):
     if ctx.resilient_parsing:
@@ -13,9 +15,10 @@ def name_callback(ctx: typer.Context, value: str):
     return value
 
 
+@app.command()
 def main(name: Annotated[Optional[str], typer.Option(callback=name_callback)] = None):
     print(f"Hello {name}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
