@@ -1,6 +1,9 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     name: str,
     lastname: str = typer.Option("", help="Last name of person to greet."),
@@ -23,4 +26,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
