@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     fullname: Annotated[
         str, typer.Option(show_default="Deadpoolio the amazing's name")
@@ -11,4 +14,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
