@@ -1,9 +1,12 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(user_name: str = typer.Option(..., "--name", "-n")):
     print(f"Hello {user_name}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
