@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     name: str,
     email: Annotated[str, typer.Option(prompt=True, confirmation_prompt=True)],
@@ -10,4 +13,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
