@@ -1,10 +1,13 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(name: str, lastname: Annotated[str, typer.Option(prompt=True)]):
     print(f"Hello {name} {lastname}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
