@@ -1,9 +1,12 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(name: str, lastname: str = typer.Option()):
     print(f"Hello {name} {lastname}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
