@@ -5,6 +5,8 @@ from typing_extensions import Annotated
 
 __version__ = "0.1.0"
 
+app = typer.Typer()
+
 
 def version_callback(value: bool):
     if value:
@@ -12,6 +14,7 @@ def version_callback(value: bool):
         raise typer.Exit()
 
 
+@app.command()
 def main(
     name: Annotated[str, typer.Option()] = "World",
     version: Annotated[
@@ -22,4 +25,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
