@@ -4,6 +4,8 @@ import typer
 
 __version__ = "0.1.0"
 
+app = typer.Typer()
+
 
 def version_callback(value: bool):
     if value:
@@ -16,6 +18,7 @@ def name_callback(name: str):
         raise typer.BadParameter("Only Camila is allowed")
 
 
+@app.command()
 def main(
     name: str = typer.Option(..., callback=name_callback),
     version: Optional[bool] = typer.Option(
@@ -26,4 +29,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
