@@ -5,6 +5,8 @@ from typing_extensions import Annotated
 
 __version__ = "0.1.0"
 
+app = typer.Typer()
+
 
 def version_callback(value: bool):
     if value:
@@ -17,6 +19,7 @@ def name_callback(name: str):
         raise typer.BadParameter("Only Camila is allowed")
 
 
+@app.command()
 def main(
     name: Annotated[str, typer.Option(callback=name_callback)],
     version: Annotated[
@@ -27,4 +30,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
