@@ -5,6 +5,8 @@ from typing_extensions import Annotated
 
 __version__ = "0.1.0"
 
+app = typer.Typer()
+
 
 def version_callback(value: bool):
     if value:
@@ -18,6 +20,7 @@ def name_callback(name: str):
     return name
 
 
+@app.command()
 def main(
     name: Annotated[str, typer.Option(callback=name_callback)],
     version: Annotated[
@@ -29,4 +32,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
