@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(force: Annotated[bool, typer.Option("--force/--no-force", "-f/-F")] = False):
     if force:
         print("Forcing operation")
@@ -10,4 +13,4 @@ def main(force: Annotated[bool, typer.Option("--force/--no-force", "-f/-F")] = F
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
