@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(in_prod: Annotated[bool, typer.Option(" /--demo", " /-d")] = True):
     if in_prod:
         print("Running in production")
@@ -10,4 +13,4 @@ def main(in_prod: Annotated[bool, typer.Option(" /--demo", " /-d")] = True):
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
