@@ -10,6 +10,10 @@ class NeuralNetwork(str, Enum):
     lstm = "lstm"
 
 
+app = typer.Typer()
+
+
+@app.command()
 def main(
     network: Annotated[
         NeuralNetwork, typer.Option(case_sensitive=False)
@@ -19,4 +23,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
