@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated, Literal
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     network: Annotated[Literal["simple", "conv", "lstm"], typer.Option()] = "simple",
 ):
@@ -9,4 +12,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
