@@ -1,10 +1,13 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(config: typer.FileText = typer.Option(...)):
     for line in config:
         print(f"Config line: {line}")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
