@@ -1,10 +1,13 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(config: typer.FileTextWrite = typer.Option(...)):
     config.write("Some config written by the app")
-    typer.echo("Config written")
+    print("Config written")
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
