@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(file: Annotated[typer.FileBinaryWrite, typer.Option()]):
     first_line_str = "some settings\n"
     # You cannot write str directly to a binary file, you have to encode it to get bytes
@@ -15,4 +18,4 @@ def main(file: Annotated[typer.FileBinaryWrite, typer.Option()]):
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
