@@ -1,6 +1,9 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     id: int = typer.Argument(..., min=0, max=1000),
     age: int = typer.Option(20, min=18),
@@ -12,4 +15,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
