@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     id: Annotated[int, typer.Argument(min=0, max=1000)],
     rank: Annotated[int, typer.Option(max=10, clamp=True)] = 0,
@@ -13,4 +16,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
