@@ -3,7 +3,10 @@ from pathlib import Path
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     config: Annotated[
         Path,
@@ -22,4 +25,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
