@@ -1,6 +1,9 @@
 import typer
 
+app = typer.Typer()
 
+
+@app.command()
 def main(username: str):
     if username == "root":
         print("The root user is reserved")
@@ -9,4 +12,4 @@ def main(username: str):
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
