@@ -12,4 +12,4 @@ runner = CliRunner()
 def test_app():
     result = runner.invoke(app, ["--name", "Camila"])
     assert result.exit_code == 0
-    assert "Hello Camila" in result.stdout
+    assert "Hello Camila" in result.output
