@@ -3,15 +3,14 @@ import subprocess
 import sys
 from unittest import mock
 
-import shellingham
 import typer
+import typer.completion
 from typer.testing import CliRunner
 
-from docs_src.commands.index import tutorial001 as mod
+from docs_src.typer_app import tutorial001 as mod
 
 runner = CliRunner()
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_completion_show_no_shell():
@@ -142,8 +141,6 @@ def test_completion_source_pwsh():
 
 
 def test_completion_show_invalid_shell():
-    with mock.patch.object(
-        shellingham, "detect_shell", return_value=("xshell", "/usr/bin/xshell")
-    ):
+    with mock.patch.object(typer.completion, "_get_shell_name", return_value="xshell"):
         result = runner.invoke(app, ["--show-completion"])
     assert "Shell xshell not supported" in result.output
