@@ -1,15 +1,13 @@
 import subprocess
 import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.arguments.default import tutorial001 as mod
 
 runner = CliRunner()
 
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_help():
