@@ -1,21 +1,18 @@
 import subprocess
 import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.arguments.help import tutorial005_an as mod
 
 runner = CliRunner()
-
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
-    assert "[OPTIONS] [NAME]" in result.output
+    assert "Usage: main [OPTIONS] [NAME]" in result.output
     assert "Arguments" in result.output
     assert "Who to greet" in result.output
     assert "[default: (Deadpoolio the amazing's name)]" in result.output
