@@ -1,7 +1,6 @@
 import subprocess
 import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.multiple_values.arguments_with_multiple_values import (
@@ -9,8 +8,7 @@ from docs_src.multiple_values.arguments_with_multiple_values import (
 )
 
 runner = CliRunner()
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_help():
