@@ -1,20 +1,19 @@
 import subprocess
 import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.multiple_values.multiple_options import tutorial001 as mod
 
 runner = CliRunner()
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_main():
     result = runner.invoke(app)
     assert result.exit_code != 0
     assert "No provided users" in result.output
+    assert "raw input = None" in result.output
     assert "Aborted" in result.output
 
 
@@ -37,8 +36,7 @@ def test_3_user():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
