@@ -2,15 +2,12 @@ import os
 import subprocess
 import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.options.callback import tutorial004 as mod
 
 runner = CliRunner()
-
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_1():
