@@ -1,14 +1,12 @@
 import subprocess
+import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.options.name import tutorial001 as mod
 
 runner = CliRunner()
-
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_option_help():
@@ -25,11 +23,16 @@ def test_call():
     assert "Hello Camila" in result.output
 
 
+def test_call_no_args():
+    result = runner.invoke(app, ["--name"])
+    assert result.exit_code != 0
+    assert "Option '--name' requires an argument" in result.output
+
+
 def test_script():
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
