@@ -1,15 +1,12 @@
 import subprocess
 import sys
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.options.name import tutorial001_an as mod
 
 runner = CliRunner()
-
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_option_help():
@@ -29,18 +26,13 @@ def test_call():
 def test_call_no_args():
     result = runner.invoke(app, ["--name"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-    assert (
-        "Option '--name' requires an argument" in result.output
-        or "--name option requires an argument" in result.output
-    )
+    assert "Option '--name' requires an argument" in result.output
 
 
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
