@@ -2,18 +2,7 @@ import sys
 from os import getenv
 
 import pytest
-
-try:
-    import shellingham
-    from shellingham import ShellDetectionFailure
-
-    shell = shellingham.detect_shell()[0]
-except ImportError:  # pragma: no cover
-    shellingham = None
-    shell = None
-except ShellDetectionFailure:  # pragma: no cover
-    shell = None
-
+from typer._completion_shared import _get_shell_name
 
 needs_py310 = pytest.mark.skipif(
     sys.version_info < (3, 10), reason="requires python3.10+"
@@ -23,8 +12,9 @@ needs_linux = pytest.mark.skipif(
     not sys.platform.startswith("linux"), reason="Test requires Linux"
 )
 
+shell = _get_shell_name()
 needs_bash = pytest.mark.skipif(
-    not shellingham or not shell or "bash" not in shell, reason="Test requires Bash"
+    shell is None or "bash" not in shell, reason="Test requires Bash"
 )
 
 requires_completion_permission = pytest.mark.skipif(
